Author: julianfoad
Date: Wed Jan 21 17:21:45 2015
New Revision: 1653609

URL: http://svn.apache.org/r1653609
Log:
Clarify an unusual 'decoded URL' parameter by renaming it. Fix a problem
whereby it was passed to the Ev2 shims (if enabled) as if it were a normal URL.

I have not investigated whether the Ev2 shims problem was real or just
theoretical, nor tried to test the Ev2 shims after this fix.

* subversion/include/svn_repos.h
  (svn_repos_get_commit_editor5): Rename 'repos_url' to 'repos_url_decoded'.
    Deduplicate the comment about copyfrom_path, following r1653600.

* subversion/libsvn_repos/commit.c
  (edit_baton): Rename 'repos_url' to 'repos_url_decoded'.
  (add_file_or_directory): Track the rename.
  (svn_repos_get_commit_editor5): Rename 'repos_url' to 'repos_url_decoded'.
    Convert to an encoded URL for passing to Ev2 shims.

Modified:
    subversion/trunk/subversion/include/svn_repos.h

Modified: subversion/trunk/subversion/include/svn_repos.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_repos.h?rev=1653609&r1=1653608&r2=1653609&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_repos.h (original)
+++ subversion/trunk/subversion/include/svn_repos.h Wed Jan 21 17:21:45 2015
@@ -1498,10 +1498,9 @@ svn_repos_replay(svn_fs_root_t *root,
  * filesystem of @a repos, beginning at location 'rev:@a base_path',
  * where "rev" is the argument given to open_root().
  *
  * @a repos is a previously opened repository.  @a repos_url is the
  * decoded URL to the base of the repository, and is used to check
- * copyfrom paths.  copyfrom paths passed to the editor must be full,
- * URI-encoded, URLs.  @a txn is a filesystem transaction object to use
+ * copyfrom paths.  @a txn is a filesystem transaction object to use
  * during the commit, or @c NULL to indicate that this function should
  * create (and fully manage) a new transaction.
  *
@@ -1537,19 +1536,19 @@ svn_repos_replay(svn_fs_root_t *root,
  *
  * @since New in 1.5.
  *
  * @note Yes, @a repos_url is a <em>decoded</em> URL.  We realize
  * that's sorta wonky.  Sorry about that.
  *
  * @note Like most commit editors, the returned editor requires that the
  * @c copyfrom_path parameter passed to its @c add_file and @c add_directory
- * methods is a URL, not a relative path.
+ * methods is a full, URI-encoded URL, not a relative path.
  */
 svn_error_t *
 svn_repos_get_commit_editor5(const svn_delta_editor_t **editor,
                              void **edit_baton,
                              svn_repos_t *repos,
                              svn_fs_txn_t *txn,
-                             const char *repos_url,
+                             const char *repos_url_decoded,
                              const char *base_path,
                              apr_hash_t *revprop_table,
                              svn_commit_callback2_t commit_callback,
@@ -1498,10 +1498,9 @@ svn_repos_replay(svn_fs_root_t *root,
  * where "rev" is the argument given to open_root().
  *
- * @a repos is a previously opened repository.  @a repos_url is the
+ * @a repos is a previously opened repository.  @a repos_url_decoded is the
  * decoded URL to the base of the repository, and is used to check
@@ -1537,19 +1536,19 @@ svn_repos_replay(svn_fs_root_t *root,
  * @since New in 1.5.
  *
- * @note Yes, @a repos_url is a <em>decoded</em> URL.  We realize
+ * @note Yes, @a repos_url_decoded is a <em>decoded</em> URL.  We realize
  * that's sorta wonky.  Sorry about that.
  *


Reply via email to